from __future__ import unicode_literals
from nose.tools import *
import pygraphviz as pgv
from os import linesep

class TestGraph:
    def setUp(self):
        self.null = pgv.AGraph()
        self.K1 = pgv.AGraph()
        self.K1.add_node(1)
        self.K3 = pgv.AGraph()
        self.K3.add_edges_from([(1,2),(1,3),(2,3)])
        self.K5 = pgv.AGraph()
        self.K5.add_edges_from([(1,2),(1,3),(1,4),(1,5),(2,3),(2,4),(2,5),(3,4),(3,5),(4,5)])
        self.P3 = pgv.AGraph()
        self.P3.add_path([1,2,3])
        self.P5 = pgv.AGraph()
        self.P5.add_path([1,2,3,4,5])


    def test_strict(self):
        A =pgv.AGraph()  # empty
        assert_true(A.is_strict())
        assert_equal(A.nodes(), [])

    def test_data(self):
        d = {'a':'b','b':'c'}
        A = pgv.AGraph(data=d) # with data
        assert_equal(sorted(A.nodes()), ['a', 'b', 'c'])
        assert_equal(sorted(A.edges()), [('a', 'b'), ('b', 'c')])


    def test_str(self):
        A = pgv.AGraph(name="test")
        assert_equal(A.string(),
"""strict graph test {
}
""".replace('\n', linesep)
)
        A = pgv.AGraph()
        assert_equal(A.string(),
"""strict graph {
}
""".replace('\n', linesep)
)

    def test_repr(self):
        A = pgv.AGraph()
        assert_equal(A.__repr__()[0:7], '<AGraph')

    def test_equal(self):
        A = pgv.AGraph()
        H = pgv. AGraph()
        assert_true(H==A)
        assert_false(H is A)

    def test_iter(self):
        assert_equal(sorted(list(self.P3.__iter__())), ['1', '2', '3'])
        assert_equal(sorted(self.P3), ['1', '2', '3'])

    def test_contains(self):
        assert_true( '1' in self.P3)
        assert_false(10 in self.P3)

    def test_len(self):
        assert_equal(len(self.P3), 3)

    def test_getitem(self):
        assert_equal(self.P3[1], ['2'])

    @raises(KeyError)
    def test_missing_getitem(self):
        a = self.P3[10]

    def test_add_remove_node(self):
        A = pgv.AGraph()
        A.add_node(1)
        assert_equal(A.nodes(), ['1'])
        A.add_node('A')
        assert_equal(sorted(A.nodes()), ['1', 'A'])
        A.add_node([1]) # nodes must be strings or have a __str__
        assert_equal(sorted(A.nodes()), ['1', 'A', '[1]'])

        A.remove_node([1])
        assert_equal(sorted(A.nodes()), ['1', 'A'])
        A.remove_node('A')
        assert_equal(A.nodes(), ['1'])
        A.remove_node(1)
        assert_equal(A.nodes(), [])
        assert_raises(KeyError, A.remove_node, 1)

    def test_add_remove_nodes_from(self):
        A = pgv.AGraph()
        A.add_nodes_from(range(3))
        assert_equal(sorted(A.nodes()), ['0', '1', '2'])
        A.remove_nodes_from(range(3))
        assert_equal(A.nodes(), [])
        assert_raises(KeyError, A.remove_nodes_from, range(3))


    def test_nodes(self):
        assert_equal(sorted(self.P3.nodes()),['1', '2', '3'])
        assert_equal(sorted(self.P3.nodes_iter()),['1', '2', '3'])
        assert_equal(sorted(self.P3.iternodes()),['1', '2', '3'])

    def test_order(self):
        assert_equal(self.P3.number_of_nodes(), 3)
        assert_equal(self.P3.order(), 3)

    def test_has_node(self):
        assert_true(self.P3.has_node(1))
        assert_true(self.P3.has_node('1'))
        assert_false(self.P3.has_node('10'))

    def test_get_node(self):
        assert_equal(self.P3.get_node(1), '1')
        one = self.P3.get_node(1)
        nh = one.get_handle()
        node = pgv.Node(self.P3,1)
        assert_equal(node.get_handle(), nh)
        assert_equal(node, '1')
        assert_raises(KeyError, pgv.Node, self.P3, 10)


    def test_add_edge(self):
        A = pgv.AGraph()
        A.add_edge(1,2)
        assert_equal(sorted(A.edges()), [('1', '2')])
        e = (2,3)
        A.add_edge(e)
        assert_equal(sorted([tuple(sorted(e)) for e in A.edges()]),
                     [('1', '2'), ('2', '3')])

    def test_add_remove_edges_from(self):
        A = pgv.AGraph()
        A.add_edges_from([(1,2),(2,3)])
        assert_equal(sorted([tuple(sorted(e)) for e in A.edges()]),
                     [('1', '2'), ('2', '3')])

        A.remove_edge(1,2)
        assert_equal(sorted(A.edges()), [('2', '3')])
        e = (2,3)
        A.remove_edge(e)
        assert_equal(A.edges(), [])
        assert_raises(KeyError, A.remove_edge, 1,2)

    def test_remove_edges_from(self):
        A = pgv.AGraph()
        A.add_edges_from([(1,2),(2,3)])
        assert_equal(sorted([tuple(sorted(e)) for e in A.edges()]),
                     [('1', '2'), ('2', '3')])
        A.remove_edges_from([(1,2),(2,3)])
        assert_equal(A.edges(), [])

    def test_edges(self):
        A = pgv.AGraph()
        A.add_edges_from([(1,2),(2,3)])
        assert_equal(sorted([tuple(sorted(e)) for e in A.edges()]),
                     [('1', '2'), ('2', '3')])
        assert_equal(sorted([tuple(sorted(e)) for e in A.edges_iter()]),
                     [('1', '2'), ('2', '3')])
        assert_equal(sorted([tuple(sorted(e)) for e in A.iteredges()]),
                     [('1', '2'), ('2', '3')])

    def test_has_edge(self):
        assert_true(self.P3.has_edge(1,2))
        assert_true(self.P3.has_edge('1','2'))
        assert_false(self.P3.has_edge('1','10'))
        assert_equal(self.P3.get_edge(1,2), ('1', '2'))
        eone = self.P3.get_edge(1,2)
        eh = eone.handle
        edge = pgv.Edge(self.P3,1,2)
        assert_equal(edge.handle, eh)
        assert_equal(edge, ('1', '2'))
        A = self.P3.copy()
        A.add_node(10)
        assert_raises(KeyError, pgv.Edge, A, 1, 10)



    def test_neighbors(self):
        A = pgv.AGraph()
        A.add_edges_from([(1,2),(2,3)])
        assert_equal(sorted(A.neighbors(2)), ['1', '3'])
        assert_equal(sorted(A.neighbors_iter(2)), ['1', '3'])
        assert_equal(sorted(A.iterneighbors(2)), ['1', '3'])


    def test_degree(self):
        A = pgv.AGraph()
        A.add_edges_from([(1,2),(2,3)])
        assert_equal(sorted(A.degree()), [1, 1, 2])
        assert_equal(sorted(A.degree_iter()), [('1', 1), ('2', 2), ('3', 1)])
        assert_equal(sorted(A.iterdegree()), [('1', 1), ('2', 2), ('3', 1)])
        assert_equal(sorted(A.iterdegree(A.nodes())),
                     [('1', 1), ('2', 2), ('3', 1)])
        assert_equal(sorted(A.iterdegree(A)), [('1', 1), ('2', 2), ('3', 1)])
        assert_equal(A.degree(1), 1)
        assert_equal(A.degree(2), 2)

    def test_size(self):
        A = pgv.AGraph()
        A.add_edges_from([(1,2),(2,3)])
        assert_equal(A.number_of_edges(), 2)
        assert_equal(A.size(), 2)

    def test_clear(self):
        A = pgv.AGraph()
        A.add_edges_from([(1,2),(2,3)])
        A.clear()
        assert_equal(A.nodes(), [])
        assert_equal(A.edges(), [])

    def test_copy(self):
        A = self.P3.copy()
        assert_equal(A.nodes(), ['1', '2', '3'])
        assert_equal(A.edges(), [('1', '2'), ('2', '3')])
        assert_equal(A, self.P3)
        assert_false(A is self.P3)
        assert_true(self.P3 is self.P3)

    def test_add_path(self):
        A = pgv.AGraph()
        A.add_path([1,2,3])
        assert_equal(A, self.P3)

    def test_add_cycle(self):
        A = pgv.AGraph()
        A.add_cycle([1,2,3])
        assert_equal(A.nodes(), ['1', '2', '3'])
        assert_equal(sorted([tuple(sorted(e)) for e in A.iteredges()]),
                     [('1', '2'), ('1', '3'), ('2', '3')])


    def test_graph_strict(self):
        A = pgv.AGraph()
        A.add_node(1)
        A.add_node(1) # silent falure
        assert_equal(A.nodes(), ['1'])
        A.add_edge(1,2)
        A.add_edge(1,2) # silent falure
        assert_equal(A.edges(), [('1', '2')])
        A.add_edge(3,3) # self-loops OK with strict
        assert_equal(A.edges(), [('1', '2'), ('3', '3')])
        assert_equal(A.nodes(), ['1', '2', '3'])

    def test_graph_not_strict(self):
        A = pgv.AGraph(strict=False)
        assert_false(A.is_strict())
        A.add_node(1)
        A.add_node(1)  # nop
        assert_equal(A.nodes(), ['1'])
        A.add_edge(1,2)
        A.add_edge(1,2)
        assert_equal(A.edges(), [('1', '2'), ('1', '2')])
        A.add_edge(3,3)
        assert_equal(A.edges(), [('1', '2'), ('1', '2'), ('3', '3')])
        assert_equal(A.nodes(), ['1', '2', '3'])

        A.add_edge('3','3','foo')
        assert_equal(A.edges(),
        [('1', '2'), ('1', '2'), ('3', '3'), ('3', '3')])
        assert_equal(A.edges(keys=True),
        [('1', '2', None), ('1', '2', None),
         ('3', '3', None), ('3', '3', 'foo')])
        eone = A.get_edge(3,3,'foo')
        eh = eone.handle
        edge = pgv.Edge(A,3,3,'foo')
        assert_equal(edge.handle, eh)
        assert_equal(edge, ('3', '3'))
        assert_equal(eone, ('3', '3'))
        assert_equal(edge.name, 'foo')


class TestDiGraphOnly(TestGraph):
    def test_edge(self):
        A =pgv.AGraph(directed=True)
        A.add_edge(1,2)
        assert_true(A.has_edge(1,2))
        assert_false(A.has_edge(2,1))
        A.add_edge(2,1)
        assert_true(A.has_edge(2,1))

    def test_edges(self):
        A = pgv.AGraph(directed=True)
        A.add_edges_from(self.P3.edges())
        assert_equal(sorted([tuple(sorted(e)) for e in A.edges()]),
                    [('1', '2'), ('2', '3')])
        assert_equal(sorted([tuple(sorted(e)) for e in A.edges_iter()]),
                    [('1', '2'), ('2', '3')])
        assert_equal(sorted([tuple(sorted(e)) for e in A.out_edges()]),
                    [('1', '2'), ('2', '3')])
        assert_equal(sorted([tuple(sorted(e)) for e in A.out_edges_iter()]),
                    [('1', '2'), ('2', '3')])
        assert_equal(sorted([tuple(sorted(e)) for e in A.in_edges()]),
                    [('1', '2'), ('2', '3')])
        assert_equal(sorted([tuple(sorted(e)) for e in A.in_edges_iter()]),
                    [('1', '2'), ('2', '3')])
        assert_equal(sorted(A.out_edges(1)), [('1', '2')])
        assert_equal(sorted(A.out_edges_iter(1)), [('1', '2')])
        assert_equal(sorted(A.in_edges(2)), [('1', '2')])
        assert_equal(sorted(A.in_edges_iter(2)), [('1', '2')])
        assert_equal(A.predecessors(1), [])
        assert_equal(list(A.predecessors_iter(1)),[])
        assert_equal(A.predecessors(2), ['1'])
        assert_equal(list(A.predecessors_iter(2)), ['1'])
        assert_equal(A.successors(1), ['2'])
        assert_equal(list(A.successors_iter(1)), ['2'])
        assert_equal(A.successors(2), ['3'])
        assert_equal(list(A.successors_iter(2)), ['3'])
        assert_equal (sorted(A.out_degree()), [0, 1, 1])
        assert_equal(sorted(A.out_degree(with_labels=True).values()),
                     [0, 1, 1])
        assert_equal(sorted(A.out_degree_iter()),
                     [('1', 1), ('2', 1), ('3', 0)])
        assert_equal(sorted(A.in_degree()), [0, 1, 1])
        assert_equal(sorted(A.in_degree_iter()),
                     [('1', 0), ('2', 1), ('3', 1)])

        assert_equal(A.in_degree(1), 0)
        assert_equal(A.out_degree(1), 1)
        assert_equal(A.in_degree(2), 1)
        assert_equal(A.out_degree(2), 1)

        assert_equal(A.string().expandtabs(0),
"""strict digraph {
1 -> 2;
2 -> 3;
}
""".replace('\n', linesep)
)

        assert_equal(A.reverse().string().expandtabs(0),
"""strict digraph {
2 -> 1;
3 -> 2;
}
""".replace('\n', linesep)
)

    def test_name(self):
        A = pgv.AGraph(name='test')
        assert_equal(A.name, 'test')
        B = A.reverse()
        assert_equal(B.name, 'test')



"""
A Python wrapper for the graphviz Agraph data structure.

Quick example::

>>> from pygraphviz import *
>>> G=AGraph()
>>> G.add_node('a')
>>> G.add_edge('b','c')
>>> print G  # doctest: +SKIP 
strict graph {
    a;
    b -- c;
}
<BLANKLINE>

See pygraphviz.AGraph for detailed documentation.

"""
#    Copyright (C) 2004-2010 by 
#    Aric Hagberg <hagberg@lanl.gov>
#    Dan Schult <dschult@colgate.edu>
#    Manos Renieris, http://www.cs.brown.edu/~er/
#    Distributed with BSD license.     
#    All rights reserved, see LICENSE for details.

from __future__ import absolute_import
from __future__ import print_function
from __future__ import division

# Release data
from . import release

if release.revision is None:
    # we probably not running in an svn directory   
    try:
        # use release data stored at installatation time.
        from . import version
        __version__ = version.__version__
        __revision__ = version.__revision__
        __date__ = version.__date__
    except ImportError:
        # version.py was not created or no longer exists
        __version__ = release.version
        __revision__ = release.revision
        __date__ = release.date
else:
    # use dynamic values, even if version.py exists
    __version__ = release.version
    __revision__ = release.revision
    __date__ = release.date

__author__   = '%s <%s>\n%s <%s>\n%s <%s>' % \
              ( release.authors['Hagberg'] + release.authors['Schult'] + \
                release.authors['Renieris'] )
__license__  = release.license

from .agraph import AGraph, Node, Edge, Attribute, ItemAttribute, DotError

__all__=[
    'AGraph',
    'Node',
    'Edge',
    'Attribute',
    'ItemAttribute',
    'DotError'
    ]


from pygraphviz.tests.test import run as test



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from nose.tools import *
import pygraphviz as pgv
import sys
_PY2 = sys.version_info[0] == 2
_TEXT_TYPE = unicode if _PY2 else str


def test_name_unicode():
    A = pgv.AGraph(name='unicode')
    assert_equal(A.name,'unicode')

def test_node_encoding():
    A = pgv.AGraph(encoding='UTF-8')
    hello='Здравствуйте!'
    A.add_node(hello)
    n=A.get_node(hello)
    assert_equal(n.name, hello)

    n.attr['goodbye']="До свидания"
    assert_equal(n.attr['goodbye'],"До свидания")

def test_edge_encoding():
    A = pgv.AGraph(encoding='UTF-8')
    hello="שלום"
    A.add_edge(hello,hello,key=1) # self loop
    e=A.get_edge(hello,hello)
    assert_equal(e.name,'1')
    assert_equal(e,(hello,hello))

    e.attr['hello']=hello
    assert_equal(e.attr['hello'], hello)

def test_from_string():
    # test unicode in from_string()
    t = '测试'
    G =pgv.AGraph()
    G.add_node(t)
    ug = _TEXT_TYPE(G)
    sg = str(G)
    G1 = pgv.AGraph(ug)
    G2 = pgv.AGraph(sg)
    assert_equal(_TEXT_TYPE(G1),_TEXT_TYPE(G2))



#!/usr/bin/env python

from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function
from __future__ import division

import pygraphviz as pgv

A=pgv.AGraph()
# add some edges
A.add_edge(1,2)
A.add_edge(2,3)
A.add_edge(1,3)
A.add_edge(3,4)
A.add_edge(3,5)
A.add_edge(3,6)
A.add_edge(4,6)
# make a subgraph with rank='same'
B=A.add_subgraph([4,5,6],name='s1',rank='same')
B.graph_attr['rank']='same'
print(A.string()) # print dot file to standard output



# -*- coding: utf-8 -*-
from nose.tools import *
import pygraphviz as pgv
from os import linesep

def test_html():
    G = pgv.AGraph(label='<Hello<BR/>Graph>')
    G.add_node('a', label='<Hello<BR/>Node>')
    s = G.add_subgraph('b', label='<Hello<BR/>Subgraph>')
    s.add_node('sa', label='<Hello<BR/>Subgraph Node b>')
    G.add_edge('a','b', label='<Hello<BR/>Edge>')
    assert_equal(G.string().expandtabs(2),
"""strict graph {
  graph [label=<Hello<BR/>Graph>];
  node [label="\\N"];
  {
    graph [label=<Hello<BR/>Subgraph>];
    sa     [label=<Hello<BR/>Subgraph Node b>];
  }
  a  [label=<Hello<BR/>Node>];
  a -- b   [label=<Hello<BR/>Edge>];
}
""".replace('\n', linesep))



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from nose.tools import *
import pygraphviz as pgv
from os import linesep

def test_edge_attributes():
    A = pgv.AGraph()
    A.add_edge(1,2,label='test',spam='eggs')
    assert_equal(A.string().expandtabs(2),
"""strict graph {
  1 -- 2   [label=test,
    spam=eggs];
}
""".replace('\n', linesep)
)

def test_edge_attributes2():
    A = pgv.AGraph()
    A.add_edge(1,2)
    one = A.get_edge(1,2)
    one.attr['label'] = 'test'
    one.attr['spam'] = 'eggs'
    assert_true('label' in one.attr)
    assert_equal(one.attr['label'], 'test')
    assert_equal(sorted(one.attr.keys()), ['label', 'spam'])
    assert_equal(A.string().expandtabs(2),
"""strict graph {
  1 -- 2   [label=test,
    spam=eggs];
}
""".replace('\n', linesep)
)
    one.attr['label'] = ''
    one.attr['spam'] = ''
    assert_equal(A.string().expandtabs(2),
"""strict graph {
  1 -- 2;
}
""".replace('\n', linesep)
)
    one.attr['label'] = 'test'
    del one.attr['label']
    assert_equal(A.string().expandtabs(2),
"""strict graph {
  1 -- 2;
}
""".replace('\n', linesep)
)

def _test_anonymous_edges():
    """graph test {\n a -- b [label="edge1"];\n a -- b [label="edge2"];\n }"""

    import os,tempfile
    fd, fname = tempfile.mkstemp()
    #os.write(d)
    #os.close(fd)
    #A = AGraph(fname)

    assert_equal(A.string().expandtabs(2),
"""graph test {
   a -- b   [label=edge1];
   a -- b   [label=edge2];
}
""".replace('\n', linesep))
    os.unlink(fname)

def test_edge_attribute_update():
    A = pgv.AGraph(strict=True)
    A.add_edge(1,2,label='test',spam='eggs')
    A.add_edge(1,2,label='update',spam='')
    assert_equal(A.string().expandtabs(2),
"""strict graph {
  1 -- 2   [label=update];
}
""".replace('\n', linesep)
)

def test_edge_attribute_update_nonstrict():
    A = pgv.AGraph(strict=False)
    A.add_edge(1,2,label='test',spam='eggs',key='one')
    A.add_edge(1,2,label='update',spam='',key='one')
    assert_equal(A.string().expandtabs(2),
"""graph {
  1 -- 2 [key=one,
  label=update];
}
""".replace('\n', linesep)
)



# -*- coding: utf-8 -*-
"""Release data for PyGraphviz."""

#    Copyright (C) 2006-2013 by 
#    Aric Hagberg <aric.hagberg@gmail.com>
#    Dan Schult <dschult@colgate.edu>
#    Manos Renieris, http://www.cs.brown.edu/~er/
#    Distributed with BSD license.     
#    All rights reserved, see LICENSE for details.


import os
import re


def write_versionfile():
    """Creates a file containing version information."""
    base = os.path.split(__file__)[0]
    versionfile = os.path.join(base, 'version.py')
    if revision is None and os.path.isfile(versionfile):
        # Unable to get revision info, so probably not in an SVN directory
        # If a version.py already exists, let's not overwrite it.
        # Useful mostly for nightly tarballs.
        return
    fh = open(versionfile, 'w')
    text = '''"""
Version information for PyGraphviz, created during installation.

Do not add this file to the repository.

"""

__version__ = '%(version)s'
__revision__ = %(revision)s
__date__ = '%(date)s'

'''
    if revision is not None:
        rev = "'%s'" % (revision,)
    else:
        rev = revision
    subs = {'version': version,
            'revision': rev,
            'date': date}
    fh.write(text % subs)
    fh.close()

def get_svn_revision():
    rev = None
    base = os.path.split(__file__)[0]
    entries_path = os.path.join(base, '.svn', 'entries')
    if os.path.isfile(entries_path):
        entries = open(entries_path, 'r').read()
        # Versions >= 7 of the entries file are flat text.  The first line is
        # the version number. The next set of digits after 'dir' is the revision.
        if re.match('(\d+)', entries):
            rev_match = re.search('\d+\s+dir\s+(\d+)', entries)
            if rev_match:
                rev = rev_match.groups()[0]
    if rev:
        return rev
    else:
        return None

name = 'pygraphviz'
version = '1.3'

# Declare current release as a development release.
# Change to False before tagging a release; then change back.
dev = False

revision = None
if dev:
    version += '.dev'   
    revision = get_svn_revision()
    if revision is not None:
        version += "%s" % revision

description = "Python interface to Graphviz"
long_description = """\
PyGraphviz is a Python interface to the Graphviz graph layout and visualization package. With PyGraphviz you can create, edit, read, write, and draw graphs using Python to access the Graphviz graph data structure and layout algorithms. PyGraphviz provides a similar programming interface to NetworkX (http://networkx.github.io). 
"""
license = 'BSD'

authors = {'Hagberg' : ('Aric Hagberg','aric.hagberg@gmail.com'),
           'Schult' : ('Dan Schult','dschult@colgate.edu'),
           'Renieris' : ('Manos Renieris','')
           }
url = 'http://pygraphviz.github.io'
download_url="https://pypi.python.org/pypi/pygraphviz"
platforms = ['Linux','Mac OSX','Microsoft :: Windows']
keywords = ['Networks', 'Graph Visualization', 'network', 'graph', 'graph drawing']
classifiers = [
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: C',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Scientific/Engineering :: Visualization',
        ]

# Get date dynamically
import time
date = time.asctime()
del time

if __name__ == '__main__':
    # Write versionfile for nightly snapshots.
    write_versionfile()




#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
A simple example to create a graphviz dot file and draw a graph.

"""
#    Copyright (C) 2006 by 
#    Aric Hagberg <hagberg@lanl.gov>
#    Dan Schult <dschult@colgate.edu>
#    Manos Renieris, http://www.cs.brown.edu/~er/
#    Distributed with BSD license.     
#    All rights reserved, see LICENSE for details.

from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function
from __future__ import division

__author__ = """Aric Hagberg (hagberg@lanl.gov)"""

import pygraphviz as pgv

A=pgv.AGraph()

A.add_edge(1,2)
A.add_edge(2,3)
A.add_edge(1,3)

print(A.string()) # print to screen
print("Wrote simple.dot")
A.write('simple.dot') # write to simple.dot

B=pgv.AGraph('simple.dot') # create a new graph from file
B.layout() # layout with default (neato)
B.draw('simple.png') # draw png
print("Wrote simple.png")



# -*- coding: utf-8 -*-
from nose.tools import *
import pygraphviz as pgv

@raises(AttributeError)
def test_drawing_error():
    A = pgv.AGraph(name='test graph')
    A.add_path([1,2,3,4])
    d = A.draw()

# this is not a very good way to test...
#def test_drawing():
#    A = pgv.AGraph(name='test graph')
#    A.add_path([1,2,3,4])
#    d = A.draw(prog='neato')
#    assert_equal(len(d.splitlines()),19)
# FIXME
# smoke test
# >>> (fd,fname)=tempfile.mkstemp()
# >>> A.draw(fname,format='ps',prog='neato')
# >>> A.draw(fname,prog='neato')

@raises(ValueError)
def test_name_error():
    A = pgv.AGraph(name='test graph')
    A.draw('foo',prog='foo')



# -*- coding: utf-8 -*-
from nose.tools import *
import pygraphviz as pgv

def test_layout():
    A = pgv.AGraph(name='test graph')
    A.add_path([1,2,3,4])
    A.layout()
    assert_equal(['pos' in n.attr for n in A.nodes()], [True, True, True, True])



# -*- coding: utf-8 -*-
"""
Example showing use of unicode and UTF-8 encoding.
"""

from __future__ import absolute_import
from __future__ import unicode_literals
from __future__ import print_function
from __future__ import division

import pygraphviz as pgv
# specify UTF-8 encoding (it is the default)
A=pgv.AGraph(encoding='UTF-8')

# nodes, attributes, etc can be strings or unicode
A.add_node(1,label='plain string')
A.add_node(2,label='unicode')

# you can enter unicode text as
hello='Здравствуйте!'
A.add_node(3,label=hello)

# or using unicode code points
hello='\u0417\u0434\u0440\u0430\u0432\u0441\u0442\u0432\u0443\u0439\u0442\u0435!'
A.add_node(hello) # unicode node label

goodbye="До свидания"
A.add_edge(1,hello,key=goodbye)

A.add_edge("שלום",hello)
#A.add_edge(1,3,hello="こんにちは / ｺﾝﾆﾁﾊ")
A.add_edge(1,"こんにちは")

print(A) # print to screen
A.write('utf8.dot') # write to simple.dot



# -*- coding: utf-8 -*-
from nose.tools import assert_equal, raises
import pygraphviz as pgv
from os import linesep


def test_name():
    A = pgv.AGraph(name='')
    assert_equal(A.string(),
"""strict graph {
}
""".replace('\n', linesep))


    assert_equal(A.string().expandtabs(),
"""strict graph {
}
""".replace('\n', linesep))

    assert_equal( A.__repr__()[0:7],'<AGraph')


def test_string_representation_small():
    A = pgv. AGraph(name='test')
    A.add_path([1,2])
    assert_equal(A.string().expandtabs(),
"""strict graph test {
        1 -- 2;
}
""".replace('\n', linesep)
)

def test_string_representation_large():
    A = pgv.AGraph(name='test graph')
    A.add_path([1,2,3,4,5,6,7,8,9,10])
    A.add_node(11)
    assert_equal(A.string().expandtabs(),
"""strict graph "test graph" {
        1 -- 2;
        2 -- 3;
        3 -- 4;
        4 -- 5;
        5 -- 6;
        6 -- 7;
        7 -- 8;
        8 -- 9;
        9 -- 10;
        11;
}
""".replace('\n', linesep))

@raises(pgv.DotError)
def test_bad_dot_input():
    A = pgv.AGraph(string='graph {1--1')
